%%
%% This is file `sduthesis-cover.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sduthesis.dtx  (with options: `cover')
%% 
%% -----------------------------------
%% 
%% This is a generated file.
%% 
%% Copyright (C) 2012 -- 2014 by Liam Huang
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is Liam Huang.
%% 
\newtoks\fenlei     % 中图分类号
\newtoks\DWdaihao   % 单位代号
\newtoks\miji       % 密级
\newtoks\StuNum     % 学号
\newtoks\Ctitle     % 中文标题
\newtoks\Cauthor    % 作者中文名
\newtoks\Cmajor     % 专业
\newtoks\Csuperver  % 导师
\newtoks\Cdate      % 中文日期
\newtoks\Dpart      % 学院
\newtoks\Grade      % 年级
\newcommand{\LeftLength}{2.3cm}
\newcommand{\RightLength}{5.5cm}
\newcommand{\Mcs}[1]{\makebox[\LeftLength][s]{{\zihao{3}\bfseries\kaishu{}#1}}}
\newcommand{\Mcc}[1]{\makebox[\RightLength][c]{{\zihao{-3}\songti{}#1}}}
\newcommand{\maketitlepage}{%
\thispagestyle{empty}
\begin{center}
~
\vskip 8mm\relax
{
  {\includegraphics[width = .7\textwidth]{SDUWords.jpg}}\\[3mm]
  {\scalebox{4}{\fzbHei{}毕业论文（设计）}}
}
\par \vskip 15mm \relax
{
  \begin{flushleft}
    {\zihao{3}\heiti{}论文（设计）题目：}
  \end{flushleft}
}
\vfill
{
  \noindent
  \zihao{-1}\kaishu\the\Ctitle
}
\vfill
{
  \begin{tabular}{p{\LeftLength}p{\RightLength}}
  \Mcs{姓名}& \Mcc{\the\Cauthor}\\[-.8mm]\cline{2-2}\\[-4mm]
  \Mcs{学号}& \Mcc{\the\StuNum}\\[-.8mm]\cline{2-2}\\[-4mm]
  \Mcs{学院}& \Mcc{\the\Dpart}\\[-.8mm]\cline{2-2}\\[-4mm]
  \Mcs{专业}& \Mcc{\the\Cmajor}\\[-.8mm]\cline{2-2}\\[-4mm]
  \Mcs{年级}& \Mcc{\the\Grade}\\[-.8mm]\cline{2-2}\\[-4mm]
  \Mcs{指导老师}& \Mcc{\the\Csuperver}\\[-.8mm]\cline{2-2}
  \end{tabular}
}
\par \vskip 20mm \relax
{
\zihao{3}\the\Cdate
}
\end{center}
\clearpage
}
%% 
%% Copyright (C) 2012 -- 2014 by Liam Huang
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is Liam Huang.
%% 
%% -----------------------------------
%% 
%% This work consists of the file  sduthesis.dtx and sduthesis.ins
%% and the derived files           sduthesis.cls,
%%                                 sduthesis-cover.def,
%%                                 sduthesis-statement.def,
%%                                 figures/,
%%                                 sduthesis-demo.tex,
%%                                 README.md,
%%                                 LICENSE.md,
%%                                 sduthesis.pdf and
%%                                 sduthesis-demo.pdf.
%%
%% End of file `sduthesis-cover.def'.
