%%
%% This is file `sduthesis-statement.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% sduthesis.dtx  (with options: `statement')
%% 
%% -----------------------------------
%% 
%% This is a generated file.
%% 
%% Copyright (C) 2012 -- 2014 by Liam Huang
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is Liam Huang.
%% 
\newcommand{\makestatement}{%
\begin{titlepage}
\vspace{2cm} {\zihao{4}\baselineskip=30pt

\centerline{\zihao{3}\bfseries 原\quad 创\quad 性\quad 声\quad 明}

\noindent\hspace*{2em}本人郑重声明：所呈交的学位论文，是本人在导师指导下，独
立进行研究所取得的成果。除文中已经注明引用的内容外，本论文不包
含任何其他个人或集体已经发表或撰写过的科研成果。对本论文的研究作出重
要贡献的个人和集体，均已在文中以明确方式标明。本声明
的法律责任由本人承担。

\vspace{13mm}

\noindent\hspace*{2em}论文作者签名：\hrulefill \hspace{1em}日\hspace{1em} 期：\hrulefill

\vspace{2.7cm}

\centerline{\zihao{3}\bfseries 关于学位论文使用授权的声明}

\noindent\hspace*{2em}本人完全了解山东大学有关保留、使用学位论文的规定，同意学
校保留或向国家有关部门或机构送交论文的复印件和电子版，允许论文被查阅
和借阅；本人授权山东大学可以将本学位论文全部或部分内容编入有关数据库
进行检索，可以采用影印、缩印或其他复制手段保存论文和汇编本学位论文。

\noindent\hspace*{2em}（保密的论文在解密后应遵守此规定）

\vspace{13mm}

\noindent\hspace*{2em}论文作者签名：\hrulefill\hrulefill\hspace{0.5em} 导师签名：\hrulefill\hrulefill\hspace{0.5em}日\hspace{0.5em}期：\hrulefill \hrulefill }
\end{titlepage}
}
%% 
%% Copyright (C) 2012 -- 2014 by Liam Huang
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is Liam Huang.
%% 
%% -----------------------------------
%% 
%% This work consists of the file  sduthesis.dtx and sduthesis.ins
%% and the derived files           sduthesis.cls,
%%                                 sduthesis-cover.def,
%%                                 sduthesis-statement.def,
%%                                 figures/,
%%                                 sduthesis-demo.tex,
%%                                 README.md,
%%                                 LICENSE.md,
%%                                 sduthesis.pdf and
%%                                 sduthesis-demo.pdf.
%%
%% End of file `sduthesis-statement.def'.
